#!/usr/bin/python3
# -*- coding: utf-8 -*-

import sys
import os
import re
import json

# Определяем тип тестирующей системы
# В отладочных целях можно заменить эти переменные на константы True/False
POLYGON = ("polygon" in os.environ.get("APPDATA", "0").lower()) or ("codeforces" in os.environ.get("APPDATA", "0").lower())
EJUDGE = "EJUDGE" in os.environ
SILVER = "SILVERTESTS_VERSION" in os.environ
SIRIUS = not(POLYGON or EJUDGE or SILVER)

# Коды возврата для передачи в функцию quit
OK = 0
WA = 1
PT = 1
PE = 2
CF = 3

# Класс для работы с ответом участника в тестирующей системе Сириуса
class AnswerSMT():
    def __init__(self, userAnswer=None, score=0, maxScore=100):
        '''считывание ответа'''
        if userAnswer is None:
            self.userAnswer = json.loads("".join(sys.stdin.readlines()))['solution']
        else:
            self.userAnswer = json.loads(userAnswer)
        
        
        '''считаем количество элементов ввода и делаем список ответов по элементам ввода'''
        if type(self.userAnswer) is dict:
            self.elements = 1
            if type(self.userAnswer['solution']) is dict:
                self.userAnswer = [[self.userAnswer['solution']['message']]]
            elif type(self.userAnswer['solution']) is int:
                self.userAnswer = [[self.userAnswer['solution']]]
            else:
                self.userAnswer = [self.userAnswer['solution']]
        else: 
            self.elements = len(self.userAnswer)
            a = []
            for i in range(0, self.elements):
                if type(self.userAnswer[i]['solution']) is int:
                    a.append([self.userAnswer[i]['solution']])
                else:
                    a.append(self.userAnswer[i]['solution'])
            self.userAnswer = a
        
        '''считаем, сколько полей ввода для каждого элемента ввода'''
        self.userAnswerLength = []
        for i in range(0, self.elements):
            if type(self.userAnswer[i]) is list:
                self.userAnswerLength.append(len(self.userAnswer[i]))
            elif self.userAnswer[i] != '':
                self.userAnswerLength.append(1)
            else:
                self.userAnswerLength.append(0)
        
        self.comment = ''
        self.score = score
        self.maxScore = maxScore
        self.verdict = 'WA'
          
    def answer(self, element=0, field=0):
        '''Возвращает ответ участника из элмента ввода с номером element.
        Если в элементе ввода несколько полей ввода, то можно указать номер поля ввода'''
        if element >= self.elements:
            return None
        else:
            a = self.userAnswer[element]
        
        if a is None:
            return None
        if field >= len(a):
            return None
        else: 
            return None if a[field] is None else str(a[field])
    
    def fields_in_element(self, element=0):
        '''Возвращает информацию о количестве полей ввода в элементе ввода'''
        if len(self.userAnswerLength) <= element: 
            return 0
        else:
            return self.userAnswerLength[element]
    
    def print_answer(self):
        '''посмотреть всё содержимое для отладки'''
        print("user answer:")
        print(self.userAnswer)
        print("number of elements")
        print(self.elements)
        print('length of elements')
        print(self.userAnswerLength)
    
    def quit(self, comment=None, score=None, maxScore=None, verdict=None):
        if not comment is None:
            self.comment = comment
        
        if not score is None:
            self.score = score
        
        if not maxScore is None:
            self.maxScore = maxScore
            
        if not verdict is None:
            self.verdict = verdict
            
        print(json.dumps({"maxScore":self.maxScore,
                          "score":self.score,
                          "comment":self.comment,
                          "verdict":self.verdict}))
        sys.exit(0)


def quit(status, log="", score=0):
    if SIRIUS:
        if status in [OK, WA] and 0 < score < 100:
            status = PT
        comment = log.replace("\n", "\n\n") # Дублируем концы строк для разметки
        sirius_ans_obj.quit(verdict=status, comment=comment, score=score)
        return
    
    if POLYGON: # Нужно в Polygon, т.к. там Windows
        sys.stdout.reconfigure(encoding='utf-8')
        sys.stderr.reconfigure(encoding='utf-8')

    # Выводим набранные баллы
    if status in [OK, WA]:
        if POLYGON:
            sys.stderr.write("points " + str(score) + "\n")
            status = 7 # Код возврата полигона, сообщающий о наличии баллов
        elif EJUDGE or SILVER:
            sys.stdout.write(str(score) + "\n")
    
    # Выводим протокол проверки
    sys.stderr.write(log)
    
    # Возвращаем код возврата
    sys.exit(status)


def init():
    global OK, WA, PE, CF, PT
    global sirius_ans_obj
    if SIRIUS:
        PE = "PE"
        WA = "WA"
        OK = "OK"
        СF = "CF"
        PT = "PT"
        # При создании объекта можно в конструктор в целях отладки передать строку с JSON, тогда ответ будет считан с этого JSON, иначе из stdin
        sirius_ans_obj = AnswerSMT()


init()

########################################################################################
# Код дальше можно править
# 
# Код этой функции надо исправить так, чтобы она возвращала ответ, полученный из JSON в Сириусе
# или полученный из файла в тестирующих системах Ejudge или Polygon
# Формат возвращаемого значения - произвольный, например, одна строка или список строк
# При необходимости можно прямо в этом коде делать quit(PE, ...)
#
# В тестирующей системе Сириуса:
# Задание состоит из "элементов" (разделов"), внутри раздела могут быть поля ввода.
# Например, задание вида "Дайте ответ для а) N = 10 б) N = 20, в) N = 30" - это три раздела, они будут визуально отделены.
# А задание вида "Напишите в ответе номера объектов, которые вы выбрали, добавляя поля по необходимости" - это один раздел с несколькими полями ввода
# При считывании данных из тестирующей системы Сириуса нужно использовать объект sirius_ans_obj
# со следующим интерфейсом.
# sirius_ans_obj.elements - количество "элементов" в ответе.
# sirius_ans_obj.fields_in_element(element=0) - возвращает количество полей ввода в элементе номер element, нумерация с нуля
# sirius_ans_obj.answer(element=0, field=0) - возвращает значение поля ввода номер field из элемента номер element, нумерация с нуля
########################################################################################

def get_answer():
    if SIRIUS:
        ans = sirius_ans_obj.answer(element=0)
        if ans is None:
            ans = ""
    elif POLYGON or SILVER:
        ans = []
        if POLYGON:
            fin = open(sys.argv[2], "r", encoding="utf8")
        elif SILVER:
            fin = sys.stdin
        ans = fin.readline()
    return ans

ans = get_answer()

ans = ans.strip().lower()

if not ans:
    quit(PE, "Ответ пустой")

ans = ans.replace("n", "h")
ans = ans.replace("н", "h")
ans = ans.replace(chr(8722), "-") # неправильный минус
 
for char in ans:
    if char not in " wh+-*0123456789()":
        quit(PE, "Answer contains wrong character: ''" + char + "''" + "\n")
if "**" in ans:
    quit(PE, "''**'' is not allowed in the answer." + "\n")
ALL_PASSED = True
 
ANSWERS = {
'w*h+h+w+2': 100, 
'w*h+9+h': 30, 
'h*w+w+h+3': 40, 
'h*w+h+w+1': 40, 
'w*h+w+4': 30, 
'4*w+5': 20, 
'w*h+w+5': 20, 
'w*h+w+h': 30, 
'10+w+h+h*w': 20, 
'w*h+h+2': 20, 
'h*w+w+h+4': 30, 
'h * (w + 2) + w': 15, 
'w*(2+h)+h+2': 10, 
'w*h-1+w': 10, 
'h*(w+1)+3': 10, 
'(1+h)*w+1': 10, 
'w*(h+1)+1+h*2': 10, 
'w*h+3+w-1': 20, 
'w*h+h-1': 10, 
'w*h-h-w+1': 10, 
'2*w+4+(w+1)*h': 10, 
'w*h+h+10': 10, 
'h*w+h+1': 10, 
'w*h+w+3': 20, 
'w*2+(w*h-1)': 10, 
'(w+1)*(h+2)-1': 10, 
'w+w*h-2': 10, 
'w*(h+2)+2': 10, 
'17+h*(w+1)': 10, 
'w+h+w*h-1': 30, 
'2*w+1+h*w': 20, 
'h*w+w+2*h-1': 10, 
'w*h+2*(w-1)': 10,  
}
 
EPS = 1e-6
try:
    for w in range(1, 11):
        for h in range(2, 11):
            for sample in list(ANSWERS.keys()):
                if abs(eval(ans) - eval(sample)) > EPS:
                    del ANSWERS[sample]
except ZeroDivisionError as E:
    quit(WA, "Division by zero occurred while evaluating an expression.\n", 0)
except Exception as E:
    quit(PE, "Incorrect expression (incorrect syntax).\n")
 
if len(ANSWERS) > 1:
    quit(CF, "Two similar expressions in the answers.\n" + str(ANSWERS), 0)
 
if len(ANSWERS) == 0:
    quit(WA, "Thi is a wrong answer.\n", 0)
 
for sample in ANSWERS:
    if ANSWERS[sample] == 100:
        quit(OK, "This is a correct answer.\n", ANSWERS[sample])
    else:
        quit(OK, "The answer is  equivalent to " + sample + ".\nThis is a wrong answer.\n", ANSWERS[sample])

