#!/usr/bin/python3
# -*- coding: utf-8 -*-
 
import sys
import os
import re
import json
 
# Определяем тип тестирующей системы
# В отладочных целях можно заменить эти переменные на константы True/False
POLYGON = ("polygon" in os.environ.get("APPDATA", "0").lower()) or ("codeforces" in os.environ.get("APPDATA", "0").lower())
EJUDGE = "EJUDGE" in os.environ
SILVER = "SILVERTESTS_VERSION" in os.environ
SIRIUS = not(POLYGON or EJUDGE or SILVER)
 
# Коды возврата для передачи в функцию quit
OK = 0
WA = 1
PT = 1
PE = 2
CF = 3

# Класc для работы с ответом участника в тестирующей системе Сириуса
class AnswerSMT():
    def __init__(self, userAnswer=None, score=0, maxScore=100):
        '''считывание ответа'''
        if userAnswer is None:
            self.userAnswer = json.loads("".join(sys.stdin.readlines()))['solution']
        else:
            self.userAnswer = json.loads(userAnswer)
        
        
        '''считаем количество элементов ввода и делаем список ответов по элементам ввода'''
        if type(self.userAnswer) is dict:
            self.elements = 1
            if type(self.userAnswer['solution']) is dict:
                self.userAnswer = [[self.userAnswer['solution']['message']]]
            elif type(self.userAnswer['solution']) is int:
                self.userAnswer = [[self.userAnswer['solution']]]
            else:
                self.userAnswer = [self.userAnswer['solution']]
        else: 
            self.elements = len(self.userAnswer)
            a = []
            for i in range(0, self.elements):
                if type(self.userAnswer[i]['solution']) is int:
                    a.append([self.userAnswer[i]['solution']])
                else:
                    a.append(self.userAnswer[i]['solution'])
            self.userAnswer = a
        
        '''считаем, сколько полей ввода для каждого элемента ввода'''
        self.userAnswerLength = []
        for i in range(0, self.elements):
            if type(self.userAnswer[i]) is list:
                self.userAnswerLength.append(len(self.userAnswer[i]))
            elif self.userAnswer[i] != '':
                self.userAnswerLength.append(1)
            else:
                self.userAnswerLength.append(0)
        
        self.comment = ''
        self.score = score
        self.maxScore = maxScore
        self.verdict = 'WA'
          
    def answer(self, element=0, field=0):
        '''Возвращает ответ участника из элмента ввода с номером element.
        Если в элементе ввода несколько полей ввода, то можно указать номер поля ввода'''
        if element >= self.elements:
            return None
        else:
            a = self.userAnswer[element]
        
        if a is None:
            return None
        if field >= len(a):
            return None
        else: 
            return None if a[field] is None else str(a[field])
    
    def fields_in_element(self, element=0):
        '''Возвращает информацию о количестве полей ввода в элементе ввода'''
        if len(self.userAnswerLength) <= element: 
            return 0
        else:
            return self.userAnswerLength[element]
    
    def print_answer(self):
        '''посмотреть всё содержимое для отладки'''
        print("user answer:")
        print(self.userAnswer)
        print("number of elements")
        print(self.elements)
        print('length of elements')
        print(self.userAnswerLength)
    
    def quit(self, comment=None, score=None, maxScore=None, verdict=None):
        if not comment is None:
            self.comment = comment
        
        if not score is None:
            self.score = score
        
        if not maxScore is None:
            self.maxScore = maxScore
            
        if not verdict is None:
            self.verdict = verdict
            
        print(json.dumps({"maxScore":self.maxScore,
                          "score":self.score,
                          "comment":self.comment,
                          "verdict":self.verdict}))
        sys.exit(0)
 
 
def quit(status, log="", score=0):
    if SIRIUS:
        if status in [OK, WA] and 0 < score < 100:
            status = PT
        comment = log.replace("\n", "\n\n") # Дублируем концы строк для разметки
        sirius_ans_obj.quit(verdict=status, comment=comment, score=score)
        return
    
    if POLYGON: # Нужно в Polygon, т.к. там Windows
        sys.stdout.reconfigure(encoding='utf-8')
        sys.stderr.reconfigure(encoding='utf-8')
 
    # Выводим набранные баллы
    if status in [OK, WA]:
        if POLYGON:
            sys.stderr.write("points " + str(score) + "\n")
            status = 7 # Код возврата полигона, сообщающий о наличии баллов
        elif EJUDGE or SILVER:
            sys.stdout.write(str(score) + "\n")
    
    # Выводим протокол проверки
    sys.stderr.write(log)
    
    # Возвращаем код возврата
    sys.exit(status)
 
 
def init():
    global OK, WA, PE, CF, PT
    global sirius_ans_obj
    if SIRIUS:
        PE = "PE"
        WA = "WA"
        OK = "OK"
        СF = "CF"
        PT = "PT"
        # При создании объекта можно в конструктор в целях отладки передать строку с JSON, тогда ответ будет считан с этого JSON, иначе из stdin
        sirius_ans_obj = AnswerSMT()
 
 
init()
 
########################################################################################
# Код дальше можно править
# 
# Код этой функции надо исправить так, чтобы она возвращала ответ, полученный из JSON в Сириусе
# или полученный из файла в тестирующих системах Ejudge или Polygon
# Формат возвращаемого значения - произвольный, например, одна строка или список строк
# При необходимости можно прямо в этом коде делать quit(PE, ...)
#
# В тестирующей системе Сириуса:
# Задание состоит из "элементов" (разделов"), внутри раздела могут быть поля ввода.
# Например, задание вида "Дайте ответ для а) N = 10 б) N = 20, в) N = 30" - это три раздела, они будут визуально отделены.
# А задание вида "Напишите в ответе номера объектов, которые вы выбрали, добавляя поля по необходимости" - это один раздел с несколькими полями ввода
# При считывании данных из тестирующей системы Сириуса нужно использовать объект sirius_ans_obj
# со следующим интерфейсом.
# sirius_ans_obj.elements - количество "элементов" в ответе.
# sirius_ans_obj.fields_in_element(element=0) - возвращает количество полей ввода в элементе номер element, нумерация с нуля
# sirius_ans_obj.answer(element=0, field=0) - возвращает значение поля ввода номер field из элемента номер element, нумерация с нуля
########################################################################################
 

from abc import ABCMeta, abstractmethod
from typing import Collection, List, Literal, NoReturn, Optional, Tuple
 

# Test case.
INPUT_FIELD: Collection[int] = list(
    map(int, "0 1 2 3 2 3 2 1 2 3 4 3 2 3 4 3 2 3 2 2 1 0 1 2 1 2 3 2 1 0".split())
)
BEST_ANSWER_MOVE_COUNT = 25
 
# Scoring.
ZERO_DISTANCE_SCORE = 60
MOVE_COUNT_PENALTY = 3
DISTANCE_PENALTY = 3
EXTRA_MOVE_AFTER_FINISH_PENALTY = 20
 

Direction = Literal["<", "=", ">"]
 

class Log(metaclass=ABCMeta):
    def __init__(self):
        self.__logs: List[str] = []
    
    def separator(self) -> None:
        self.__log("")
 
    def record_move(self, n: int, left: Direction, right: Direction) -> None:
        self.__log(self.fmt_record_move(n=n, left=left, right=right))
 
    def record_position(
        self, left_pos: int, right_pos: int, height: int, distance: int
    ) -> None:
        self.__log(
            self.fmt_record_position(
                left_pos=left_pos, right_pos=right_pos, height=height, distance=distance
            )
        )
 
    def record_invalid_move_boundry(self, is_left: bool, is_right: bool) -> None:
        self.__log(
            self.fmt_record_invalid_move_boundry(is_left=is_left, is_right=is_right)
        )
 
    def record_invalid_move_height(
        self, left_pos: int, right_pos: int, left_height: int, right_height: str
    ) -> None:
        self.__log(
            self.fmt_record_invalid_move_height(
                left_pos=left_pos,
                right_pos=right_pos,
                left_height=left_height,
                right_height=right_height,
            )
        )
 
    def record_meet(self, move_count: int) -> None:
        self.__log(self.fmt_record_meet(move_count=move_count))
 
    def record_verdict_shortest(self) -> None:
        self.__log(self.fmt_record_verdict_shortest())
 
    def record_verdict_not_shortest(self, move_count: int) -> None:
        self.__log(self.fmt_record_verdict_not_shortest(move_count=move_count))
 
    def record_verdict_not_met(self, best_distance: int) -> None:
        self.__log(self.fmt_record_verdict_not_met(best_distance=best_distance))
 
    def get_log(self) -> str:
        return "\n".join(self.__logs) + "\n"
 
    def __log(self, msg: str):
        self.__logs.append(msg)
 
    @abstractmethod
    def fmt_record_move(self, int, left: Direction, right: Direction) -> str:
        raise NotImplementedError
 
    @abstractmethod
    def fmt_incorrect_move_str_len(self, int, s: str) -> str:
        raise NotImplementedError
 
    @abstractmethod
    def fmt_incorrect_move_unexpected_chars(
        self, int, s: str, invalid_characters: Collection[str]
    ) -> str:
        raise NotImplementedError
 
    @abstractmethod
    def fmt_record_position(
        self, left_pos: int, right_pos: int, height: int, distance: int
    ) -> str:
        raise NotImplementedError
 
    @abstractmethod
    def fmt_record_invalid_move_boundry(self, s_left: bool, is_right: bool) -> str:
        raise NotImplementedError
 
    @abstractmethod
    def fmt_record_invalid_move_height(
        self, left_pos: int, right_pos: int, left_height: int, right_height: str
    ) -> str:
        raise NotImplementedError
 
    @abstractmethod
    def fmt_record_meet(self, move_count: int) -> str:
        raise NotImplementedError
 
    @abstractmethod
    def fmt_record_verdict_shortest(self) -> str:
        raise NotImplementedError
 
    @abstractmethod
    def fmt_record_verdict_not_shortest(self, move_count: int) -> str:
        raise NotImplementedError
 
    @abstractmethod
    def fmt_record_verdict_not_met(self, best_distance: int) -> str:
        raise NotImplementedError
 
 
class RuLog(Log):
    def fmt_record_move(self, n: int, left: Direction, right: Direction) -> str:
        return (
            f"Ход {n}: Залина {self.__fmt_move(left)}, Алан {self.__fmt_move(right)}."
        )
 
    def fmt_incorrect_move_str_len(self, n: int, s: str) -> str:
        return (
            f"Для хода {n} введена некорректная строка `{s}` длины {len(s)}. "
            f"Все строки ходов должны иметь длину 2."
        )
 
    def fmt_incorrect_move_unexpected_chars(
        self, n: int, s: str, invalid_characters: Collection[str]
    ) -> str:
        invalid_characters_str = ", ".join(map(lambda x: f"`{x}`", invalid_characters))
        return (
            f"Для хода {n} введена некорректная строка `{s}`, "
            f"содержащая недопустимые символы {invalid_characters_str}."
        )
 
    def fmt_record_position(
        self, left_pos: int, right_pos: int, height: int, distance: int
    ) -> str:
        return (
            f"Залина находится в точке x={left_pos}, "
            f"Алан находится в точке x={right_pos} на высоте {height}. "
            f"Расстояние между ними — {distance}."
        )
 
    def fmt_record_invalid_move_boundry(self, is_left: bool, is_right: bool) -> str:
        if is_left and is_right:
            return "Некорректный ход: Залина и Алан вышли за границы ломаной."
        if is_left:
            return "Некорректный ход: Залина вышла за границы ломаной."
        if is_right:
            return "Некорректный ход: Алан вышел за границы ломаной."
        raise ValueError("Empty group")
 
    def fmt_record_invalid_move_height(
        self, left_pos: int, right_pos: int, left_height: int, right_height: str
    ) -> str:
        return (
            f"Некорректный ход: Залина находится в точке "
            f"x={left_pos} на высоте {left_height}, "
            f"Алан находится в точке x={right_pos} "
            f"на высоте {right_height}. "
            f"Их звонок прервался."
        )
 
    def fmt_record_meet(self, move_count: int) -> str:
        return f"Залина и Алан встретились за {move_count} ходов."
 
    def fmt_record_verdict_shortest(self) -> str:
        return "Вы нашли оптимальное решение задачи."
 
    def fmt_record_verdict_not_shortest(self, move_count: int) -> str:
        return (
            f"Залина и Алан встретились, пройдя всего {move_count} ходов. "
            f"Это не оптимальное решение задачи."
        )
 
    def fmt_record_verdict_not_met(self, best_distance: int) -> str:
        return "Залина и Алан не встретились."
 
    def __fmt_move(self, direction: Direction):
        if direction == "<":
            return "идёт влево"
        if direction == ">":
            return "идёт вправо"
        if direction == "=":
            return "стоит на месте"
        raise ValueError(f"Unexpected direction {direction}")
 
 
class EnLog(Log):
    def fmt_record_move(self, n: int, left: Direction, right: Direction) -> str:
        return (
            f"Move {n}: Zalina {self.__fmt_move(left)}, Alan {self.__fmt_move(right)}."
        )
 
    def fmt_incorrect_move_str_len(self, n: int, s: str) -> str:
        return (
            f"Move {n} got an invalid string `{s}` of length {len(s)}. "
            f"All move strings must be of length 2."
        )
 
    def fmt_incorrect_move_unexpected_chars(
        self, n: int, s: str, invalid_characters: Collection[str]
    ) -> str:
        invalid_characters_str = ", ".join(map(lambda x: f"`{x}`", invalid_characters))
        return (
            f"Move {n} got an invalid string `{s}`, containing "
            f"unexpected characters {invalid_characters_str}."
        )
 
    def fmt_record_position(
        self, left_pos: int, right_pos: int, height: int, distance: int
    ) -> str:
        return (
            f"Zalina is at x={left_pos}, Alan is at x={right_pos} at altitude {height}. "
            f"The distance between them is {distance}."
        )
 
    def fmt_record_invalid_move_boundry(self, is_left: bool, is_right: bool) -> str:
        if is_left and is_right:
            return "Invalid move: Zalina and Alan got out of the chain boundaries."
        if is_left:
            return "Invalid move: Zalina got out of the chain boundaries."
        if is_right:
            return "Invalid move: Alan got out of the chain boundaries."
        raise ValueError("Empty group")
 
    def fmt_record_invalid_move_height(
        self, left_pos: int, right_pos: int, left_height: int, right_height: str
    ) -> str:
        return (
            f"Invalid move: Zalina is at x={left_pos} at altitude {left_height}, "
            f"Alan is at x={right_pos} at altitude {right_height}. Their call hanged up."
        )
 
    def fmt_record_meet(self, move_count: int) -> str:
        return f"Zalina and Alan reached each other after {move_count} moves."
 
    def fmt_record_verdict_shortest(self) -> str:
        return "Your solution was optimal."
 
    def fmt_record_verdict_not_shortest(self, move_count: int) -> str:
        return (
            f"Zalina and Alan reached each other within a total of {move_count} moves. "
            f"Your solution was not optional."
        )
 
    def fmt_record_verdict_not_met(self, best_distance: int) -> str:
        return "Zalina and Alan did not reach each other."
 
    def __fmt_move(self, direction: Direction):
        if direction == "<":
            return "is moving to the left"
        if direction == ">":
            return "is moving to the right"
        if direction == "=":
            return "is not moving"
        raise ValueError(f"Unexpected direction {direction}")
 
 
def get_answer() -> Collection[str]:
    ans = []
    if SIRIUS:
        ans_tmp = sirius_ans_obj.answer().split('\n')
        for el in ans_tmp:
            ans.append(el.strip())
        '''
        for idx in range(sirius_ans_obj.elements):
            elem = sirius_ans_obj.answer(element=idx)
            if elem is None:
                elem = ""
            ans.append(elem.strip())
        '''
    elif POLYGON or SILVER:
        ans = []
        if POLYGON:
            fin = open(sys.argv[2], "r", encoding="utf8")
        elif SILVER:
            fin = sys.stdin
        for elem in fin:
            ans.append(elem.strip())
    return ans
 

def get_score(
    *,
    log: Log,
    best_distance: int,
    finish_move_count: Optional[int],
    move_count: int,
    is_extra_move_after_finish: bool,
) -> Tuple[int, int]:
    if finish_move_count is None:
        log.record_verdict_not_met(best_distance)
        score = max(0, ZERO_DISTANCE_SCORE - best_distance * MOVE_COUNT_PENALTY)
        return WA, score
 
    if finish_move_count < BEST_ANSWER_MOVE_COUNT:
        quit(
            CF,
            (
                f"Participant answer {finish_move_count} "
                f"was better than jury {BEST_ANSWER_MOVE_COUNT}"
            ),
        )
 
    move_count_penalty = min(
        (finish_move_count - BEST_ANSWER_MOVE_COUNT) * DISTANCE_PENALTY,
        100 - ZERO_DISTANCE_SCORE,
    )
    extra_move_penalty = (
        EXTRA_MOVE_AFTER_FINISH_PENALTY if is_extra_move_after_finish else 0
    )
 
    if move_count_penalty == 0 and extra_move_penalty == 0:
        log.record_verdict_shortest()
    else:
        log.record_verdict_not_shortest(move_count)
 
    verdict = WA if is_extra_move_after_finish else OK
    score = 100 - move_count_penalty - extra_move_penalty
    return verdict, score
 

OUT_MAPPING = {
    "<": -1,
    "=": 0,
    ">": 1,
}
 

def find_invalid_chars(s: str) -> Collection[str]:
    return set(ch for ch in s if ch not in OUT_MAPPING)
 

def clean_up_output(lines: Collection[str]) -> Collection[str]:
    ret: List[str] = []
    for line in lines:
        line_without_spaces = re.sub(r"\s+", "", line, flags=re.UNICODE)
        if line_without_spaces:
            ret.append(line_without_spaces)
    return ret
 
    
def run_checker(log: Log) -> NoReturn:
    ans = get_answer()
    ans = clean_up_output(ans)
 
    n = len(INPUT_FIELD) - 1
    p1, p2 = 0, n
    move_count = 0
    best_distance = n
    finish_move_count: Optional[int] = None
    is_extra_move_after_finish = False
 
    log.record_position(
        left_pos=p1, right_pos=p1, height=INPUT_FIELD[p1], distance=abs(p1 - p2)
    )
 
    for line in ans:
        log.separator()
 
        move_count += 1
        if finish_move_count is not None:
            is_extra_move_after_finish = True
 
        if len(line) != 2:
            quit(PE, log.fmt_incorrect_move_str_len(move_count, line))
 
        invalid_chars = find_invalid_chars(line)
        if invalid_chars:
            quit(
                PE,
                log.fmt_incorrect_move_unexpected_chars(
                    move_count, line, invalid_chars
                ),
            )
 
        log.record_move(move_count, line[0], line[1])
 
        np1 = p1 + OUT_MAPPING[line[0]]
        np2 = p2 + OUT_MAPPING[line[1]]
 
        # We don't need to update the verdict, as OK is only possible
        # if they've met without any extra move.
        if not (0 <= np1 <= n) or not (0 <= np2 <= n):
            log.record_invalid_move_boundry(
                is_left=not (0 <= np1 <= n), is_right=not (0 <= np2 <= n)
            )
            break
        if INPUT_FIELD[np1] != INPUT_FIELD[np2]:
            log.record_invalid_move_height(
                left_pos=np1,
                right_pos=np2,
                left_height=INPUT_FIELD[np1],
                right_height=INPUT_FIELD[np2],
            )
            break
 
        p1, p2 = np1, np2
        best_distance = min(best_distance, abs(p1 - p2))
        log.record_position(
            left_pos=p1, right_pos=p2, height=INPUT_FIELD[p1], distance=abs(p1 - p2)
        )
 
        if p1 == p2 and finish_move_count is None:
            log.record_meet(move_count)
            finish_move_count = move_count
 
    log.separator()
    verdict, score = get_score(
        log=log,
        best_distance=best_distance,
        finish_move_count=finish_move_count,
        move_count=move_count,
        is_extra_move_after_finish=is_extra_move_after_finish,
    )
    quit(verdict, log.get_log(), score)
 
 
LANG_TO_LOG = {
    "RU": RuLog(),
    "EN": EnLog(),
}
 

if __name__ == "__main__":
    lang = os.getenv("CHECKER_LANG", "RU")
    run_checker(LANG_TO_LOG[lang])
