#!/usr/bin/python3
# -*- coding: utf-8 -*-

import sys
import os
import re
import json
import math
import string

# Определяем тип тестирующей системы
# В отладочных целях можно заменить эти переменные на константы True/False
POLYGON = ("polygon" in os.environ.get("APPDATA", "0").lower()) or (
        "codeforces" in os.environ.get("APPDATA", "0").lower())
EJUDGE = "EJUDGE" in os.environ
SILVER = "SILVERTESTS_VERSION" in os.environ
SIRIUS = not(POLYGON or EJUDGE or SILVER)

# Коды возврата для передачи в функцию quit
OK = 0
WA = 1
PT = 1
PE = 2
CF = 3


# Класс для работы с ответом участника в тестирующей системе Сириуса
class AnswerSMT():
    def __init__(self, userAnswer=None, score=0, maxScore=100):
        '''считывание ответа'''
        if userAnswer is None:
            self.userAnswer = json.loads("".join(sys.stdin.readlines()))['solution']
        else:
            self.userAnswer = json.loads(userAnswer)

        '''считаем количество элементов ввода и делаем список ответов по элементам ввода'''
        if type(self.userAnswer) is dict:
            self.elements = 1
            if type(self.userAnswer['solution']) is dict:
                self.userAnswer = [[self.userAnswer['solution']['message']]]
            elif type(self.userAnswer['solution']) is int:
                self.userAnswer = [[self.userAnswer['solution']]]
            else:
                self.userAnswer = [self.userAnswer['solution']]
        else:
            self.elements = len(self.userAnswer)
            a = []
            for i in range(0, self.elements):
                if type(self.userAnswer[i]['solution']) is int:
                    a.append([self.userAnswer[i]['solution']])
                else:
                    a.append(self.userAnswer[i]['solution'])
            self.userAnswer = a

        '''считаем, сколько полей ввода для каждого элемента ввода'''
        self.userAnswerLength = []
        for i in range(0, self.elements):
            if type(self.userAnswer[i]) is list:
                self.userAnswerLength.append(len(self.userAnswer[i]))
            elif self.userAnswer[i] != '':
                self.userAnswerLength.append(1)
            else:
                self.userAnswerLength.append(0)

        self.comment = ''
        self.score = score
        self.maxScore = maxScore
        self.verdict = 'WA'

    def answer(self, element=0, field=0):
        '''Возвращает ответ участника из элмента ввода с номером element.
        Если в элементе ввода несколько полей ввода, то можно указать номер поля ввода'''
        if element >= self.elements:
            return None
        else:
            a = self.userAnswer[element]

        if a is None:
            return None
        if field >= len(a):
            return None
        else:
            return None if a[field] is None else str(a[field])

    def fields_in_element(self, element=0):
        '''Возвращает информацию о количестве полей ввода в элементе ввода'''
        if len(self.userAnswerLength) <= element:
            return 0
        else:
            return self.userAnswerLength[element]

    def print_answer(self):
        '''посмотреть всё содержимое для отладки'''
        print("user answer:")
        print(self.userAnswer)
        print("number of elements")
        print(self.elements)
        print('length of elements')
        print(self.userAnswerLength)

    def quit(self, comment=None, score=None, maxScore=None, verdict=None):
        if not comment is None:
            self.comment = comment

        if not score is None:
            self.score = score

        if not maxScore is None:
            self.maxScore = maxScore

        if not verdict is None:
            self.verdict = verdict

        print(json.dumps({"maxScore": self.maxScore,
                          "score": self.score,
                          "comment": self.comment,
                          "verdict": self.verdict}))
        sys.exit(0)


def quit(status, log="", score=0):
    if SIRIUS:
        if status in [OK, WA] and 0 < score < 100:
            status = PT
        comment = log.replace("\n", "\n\n") # Дублируем концы строк для разметки
        sirius_ans_obj.quit(verdict=status, comment=comment, score=score)
        return
    
    if POLYGON: # Нужно в Polygon, т.к. там Windows
        sys.stdout.reconfigure(encoding='utf-8')
        sys.stderr.reconfigure(encoding='utf-8')

    # Выводим набранные баллы
    if status in [OK, WA]:
        if POLYGON:
            sys.stderr.write("points " + str(score) + "\n")
            status = 7 # Код возврата полигона, сообщающий о наличии баллов
        elif EJUDGE or SILVER:
            sys.stdout.write(str(score) + "\n")
    
    # Выводим протокол проверки
    sys.stderr.write(log)
    
    # Возвращаем код возврата
    sys.exit(status)


def init():
    global OK, WA, PE, CF, PT
    global sirius_ans_obj
    if SIRIUS:
        PE = "PE"
        WA = "WA"
        OK = "OK"
        СF = "CF"
        PT = "PT"
        # При создании объекта можно в конструктор в целях отладки передать строку с JSON, тогда ответ будет считан с этого JSON, иначе из stdin
        sirius_ans_obj = AnswerSMT()


init()

########################################################################################
# Код дальше можно править
#
# Код этой функции надо исправить так, чтобы она возвращала ответ, полученный из JSON в Сириусе
# или полученный из файла в тестирующих системах Ejudge или Polygon
# Формат возвращаемого значения - произвольный, например, одна строка или список строк
# При необходимости можно прямо в этом коде делать quit(PE, ...)
#
# В тестирующей системе Сириуса:
# Задание состоит из "элементов" (разделов"), внутри раздела могут быть поля ввода.
# Например, задание вида "Дайте ответ для а) N = 10 б) N = 20, в) N = 30" - это три раздела, они будут визуально отделены.
# А задание вида "Напишите в ответе номера объектов, которые вы выбрали, добавляя поля по необходимости" - это один раздел с несколькими полями ввода
# При считывании данных из тестирующей системы Сириуса нужно использовать объект sirius_ans_obj
# со следующим интерфейсом.
# sirius_ans_obj.elements - количество "элементов" в ответе.
# sirius_ans_obj.fields_in_element(element=0) - возвращает количество полей ввода в элементе номер element, нумерация с нуля
# sirius_ans_obj.answer(element=0, field=0) - возвращает значение поля ввода номер field из элемента номер element, нумерация с нуля
########################################################################################


data = """166,16,1,3820
732,18,7,2440
162,14,8,940
231,18,3,2340
360,17,3,840
182,16,4,540
280,16,3,720
928,17,2,500
280,16,6,840
554,16,1,3640
360,17,1,640
610,18,3,2860
360,17,1,780
267,18,9,2280
302,16,1,3980
411,16,2,3380
231,18,4,2040
679,17,3,960
847,18,7,2600
927,17,2,900
231,18,4,2000
969,17,2,740
969,17,7,500
270,16,1,1000
349,17,15,700
159,16,7,3000
367,16,1,680
325,17,5,700
702,18,1,2440
661,18,8,2540
881,14,5,4500
732,18,1,2580
149,16,7,3400
610,18,2,2580
629,16,1,3880
554,16,2,3300
992,16,3,980
881,14,2,3440
698,16,5,3400
162,14,1,900
420,18,10,2120
732,18,3,2280
149,16,1,3040
182,16,1,920
881,14,19,4080
367,16,4,620
208,15,6,3760
270,16,4,640
299,16,6,620
928,17,8,600
698,16,1,3080
928,17,2,700
349,17,8,960
679,17,10,840
944,16,1,3880
928,17,3,700
159,16,1,3540
162,14,8,980
367,16,2,980
698,16,1,3200
166,16,9,3220
231,18,1,2780
610,18,14,2600
969,17,1,860
969,17,2,800
704,29,29,2620
162,14,3,520
702,18,5,2320
162,14,8,880
227,16,1,3560
818,27,14,740
227,16,15,3240
149,16,3,3060
595,15,7,920
711,18,3,2620
162,14,1,980
302,16,2,3220
884,13,4,3780
661,18,1,2980
208,15,9,4900
927,17,2,880
270,16,1,880
992,16,1,580
420,18,3,2300
629,16,3,3980
595,15,5,720
679,17,7,900
661,18,3,2280
411,16,4,3880
182,16,6,860
162,14,6,700
130,13,8,540
554,16,12,3240
847,18,2,2520
595,15,7,880
847,18,3,3000
992,16,3,580
420,18,9,2660
437,18,2,2640
661,18,2,2480
992,16,3,780
595,15,1,620
325,17,2,740
595,15,4,1000
162,14,12,880
702,18,2,2700
166,16,3,3440
881,14,1,4080
349,17,5,660
732,18,1,2240
661,18,2,2120
977,16,6,2340
208,15,6,3860
698,16,1,3460
182,16,3,580
629,16,3,3920
610,18,2,2860
661,18,2,2920
661,18,1,2820
927,17,2,700
208,15,2,4280
711,18,5,2420
629,16,5,3180
992,16,1,940
130,13,1,820
162,14,1,600
944,16,7,3700
325,17,1,860
955,26,202,4500
665,7,246,4620
367,16,6,660
992,16,14,740
977,16,3,2440
130,13,1,620
302,16,9,3740
969,17,1,980
437,18,2,2660
928,17,1,800
420,18,3,3000
884,13,2,3720
280,16,2,780
610,18,6,2180
881,14,1,4440
267,18,1,2700
884,13,5,3340
349,17,5,580
927,17,1,940
349,17,1,500
360,17,4,580
992,16,2,840
149,16,4,3940
159,16,1,3240
732,18,5,2640
665,7,12,600
847,18,6,2800
610,18,1,2260
927,17,8,560
928,17,2,500
944,16,1,3760
702,18,1,2760
166,16,1,3320
411,16,3,3020
407,18,3,2540
270,16,1,880
881,14,1,3980
407,18,3,2800
325,17,5,520
325,17,1,780
884,13,2,4060
231,18,2,2880
360,17,7,560
927,17,1,920
130,13,2,920
325,17,1,680
593,14,110,2220
698,16,3,3440
927,17,13,960
267,18,1,2460
732,18,10,2120
149,16,3,3680
159,16,1,3740
610,18,3,2780
227,16,13,3000
884,13,6,4620
420,18,2,2480
554,16,6,3180
227,16,1,3140
732,18,10,2500
325,17,1,560
231,18,2,2580
270,16,4,800
969,17,2,600
847,18,7,2600
702,18,1,2400
884,13,15,3860
159,16,2,3520
554,16,10,3160
698,16,1,3080
411,16,2,3520
407,18,1,2960
280,16,20,840
149,16,2,3760
629,16,5,3000
992,16,8,740
367,16,4,500
437,18,2,2700
208,15,1,4120
159,16,4,3020
554,16,1,3260
610,18,4,2720
698,16,2,3680
420,18,13,2560
159,16,2,3860
969,17,14,780
411,16,3,3800
166,16,1,3380
182,16,5,640
367,16,11,500
629,16,5,3700
299,16,1,900
992,16,2,680
166,16,4,3420
702,18,1,2620
182,16,5,760
162,14,4,500
992,16,2,520
928,17,1,740
927,17,3,800
595,15,5,580
270,16,19,760
182,16,3,940
280,16,6,940
595,15,2,560
698,16,2,3020
698,16,4,3660
420,18,1,2020
227,16,4,3300
270,16,2,860
944,16,1,3180
928,17,1,860
711,18,1,2140
645,26,241,4840
554,16,8,3520
610,18,1,2500
267,18,1,2580
360,17,8,620
299,16,2,880
928,17,2,1000
610,18,4,2360
711,18,9,2600
231,18,3,2020
698,16,1,3660
407,18,2,2880
992,16,1,780
884,13,2,4460
349,17,2,760
349,17,3,500
360,17,4,1000
992,16,7,540
360,17,1,820
992,16,1,520
162,14,2,800
698,16,2,3400
679,17,2,720
299,16,7,980
411,16,5,3720
407,18,1,2060
227,16,3,3360
182,16,2,960
847,18,1,2440
711,18,3,2620
818,27,116,2640
437,18,5,2800
884,13,6,4620
208,15,8,3140
149,16,1,3960
944,16,4,3360
944,16,1,3620
227,16,4,3280
992,16,10,740
711,18,2,2280
325,17,5,560
992,16,1,940
847,18,2,2980
420,18,2,2040
661,18,1,2680
437,18,5,2660
166,16,1,3900
595,15,3,500
554,16,14,3220
969,17,2,660
944,16,15,3620
661,18,5,2540
270,16,1,760
711,18,4,2320
130,13,4,520
231,18,5,2080
977,16,3,2960
437,18,14,2260
231,18,10,3000
884,13,2,3820
698,16,2,3540
711,18,10,2420
661,18,4,2920
969,17,7,900
182,16,11,720
267,18,2,2740
437,18,2,2260
166,16,3,3640
227,16,1,3480
661,18,5,2260
302,16,3,3760
927,17,5,820
992,16,3,960
884,13,4,4160
711,18,2,2780
881,14,3,3240
629,16,1,3860
325,17,14,960
299,16,1,700
130,13,7,520
162,14,3,880
182,16,2,800
702,18,3,2880
847,18,2,2080
702,18,2,2420
166,16,15,3900
411,16,3,3780
267,18,2,2800
325,17,14,940
159,16,3,3780
928,17,4,520
420,18,3,2780
182,16,2,720
927,17,4,560
711,18,3,2240
302,16,8,3520
732,18,3,2680
208,15,5,3500
162,14,1,600
267,18,1,2120
969,17,1,860
407,18,7,2620
977,16,4,2000
227,16,9,3400
325,17,1,780
679,17,2,960
928,17,4,900
969,17,5,820
595,15,4,520
702,18,5,2960
944,16,10,3700
977,16,3,2940
208,15,2,4240
149,16,17,3180
437,18,5,2840
267,18,6,2140
299,16,24,600
661,18,3,2800
130,13,1,520
969,17,1,980
595,15,8,920
182,16,4,620
554,16,5,3640
280,16,1,900
182,16,3,620
182,16,8,800
280,16,2,500
227,16,3,3500
702,18,2,2820
661,18,11,2140
629,16,3,3640
267,18,5,2660
554,16,8,3500
610,18,2,2400
927,17,2,980
130,13,1,560
437,18,1,2800
411,16,2,3140
661,18,2,2000
610,18,3,2540
166,16,7,3420
944,16,6,3640
349,17,3,580
969,17,1,680
367,16,1,720
367,16,2,660
360,17,17,500
554,16,1,3660
881,14,3,4660
149,16,2,4000
554,16,2,3400
162,14,3,560
732,18,1,2560
881,14,4,4440
267,18,1,2340
595,15,4,660
360,17,2,920
944,16,1,3700
349,17,6,880
884,13,10,4940
208,15,10,3820
928,17,1,1000
270,16,4,640
407,18,4,2800
407,18,2,2640
969,17,7,860
182,16,2,580
302,16,1,3280
270,16,1,580
847,18,16,2020
208,15,7,3240
325,17,2,960
661,18,1,2400
407,18,2,2760
928,17,3,600
349,17,8,700
702,18,6,2340
437,18,2,2640
367,16,2,560
349,17,1,840
267,18,2,2320
130,13,1,540
420,18,3,2720
149,16,2,3060
437,18,9,2900
732,18,4,2000
698,16,6,4000
679,17,2,820
884,13,1,4300
149,16,2,3620
182,16,2,940
267,18,6,3000
437,18,1,2620
977,16,2,2620
267,18,1,2680
166,16,6,3560
927,17,1,800
610,18,8,2800
270,16,7,600
267,18,5,2580
231,18,2,2680
554,16,2,3500
977,16,3,2560
270,16,2,600
149,16,11,3140
702,18,1,2280
679,17,5,800
208,15,3,4580
928,17,6,980
554,16,2,3460
629,16,2,3780
166,16,5,3180
629,16,12,3280
847,18,3,2060
227,16,10,3100
299,16,6,860
208,15,4,3660
595,15,2,760
166,16,3,3780
969,17,1,720
702,18,4,2940
166,16,4,3400
407,18,3,2960
227,16,6,3080
227,16,5,3420
969,17,3,860
411,16,2,3860
679,17,5,540
881,14,6,4060
437,18,7,2520
349,17,10,540
732,18,6,2840
411,16,2,3240
270,16,1,920
992,16,1,980
955,26,134,740
661,18,2,2620
977,16,7,2320
360,17,5,940
270,16,1,900
208,15,10,3440
182,16,6,960
302,16,5,3940
302,16,8,3660
231,18,6,2120
629,16,6,3840
420,18,2,2960
927,17,2,580
325,17,4,720
349,17,1,620
732,18,5,2220
130,13,2,660
969,17,3,520
130,13,3,960
711,18,5,2100
711,18,2,2240
698,16,15,3580
231,18,1,2840
702,18,3,2380
159,16,5,3840
928,17,2,860
437,18,2,2320
944,16,4,3280
807,4,235,3880
227,16,2,3180
977,16,4,2400
182,16,3,540
437,18,3,2920
280,16,1,780
969,17,1,700
884,13,1,3400
299,16,6,900
280,16,19,520
992,16,2,880
407,18,1,2280
162,14,3,760
325,17,2,520
969,17,9,580
280,16,4,600
711,18,3,2900
227,16,4,3380
992,16,3,1000
153,9,1,2940
407,18,1,2240
969,17,2,960
153,9,7,3680
437,18,3,2140
969,17,7,620
702,18,5,2780
367,16,10,1000
928,17,7,660
732,18,1,2860
270,16,2,540
732,18,3,2860
698,16,1,3860
360,17,1,980
420,18,4,2100
704,29,28,1500
325,17,1,700
702,18,2,2860
595,15,1,840
886,8,20,3680
944,16,8,3240
302,16,1,3380
267,18,1,2800
420,18,7,2120
420,18,1,2180
792,14,259,1740
437,18,1,2100
992,16,3,920
302,16,20,4000
367,16,8,960
299,16,4,940
944,16,1,3040
420,18,2,2120
367,16,1,820
992,16,2,860
702,18,4,2760
325,17,3,640
881,14,7,4200
792,14,46,2300
927,17,11,900
407,18,9,2080
884,13,3,4560
732,18,4,2960
927,17,2,640
267,18,4,2500
702,18,1,2840
928,17,2,780
944,16,7,3120
881,14,5,4800
977,16,6,2260
325,17,1,520
992,16,1,660
280,16,2,800
149,16,1,4000
227,16,7,3260
166,16,5,3040
411,16,6,3320
969,17,3,540
679,17,4,960
661,18,3,2380
661,18,3,2500
711,18,2,2220
280,16,1,860
130,13,2,700
610,18,7,2940
367,16,12,1000
610,18,1,2780
711,18,1,2680
130,13,2,620
159,16,5,3000
162,14,2,660
166,16,14,3360
130,13,14,640
280,16,4,820
360,17,1,500
927,17,6,820
270,16,2,600
159,16,4,3860
411,16,7,3100
149,16,12,3700
270,16,7,800
299,16,5,840
407,18,1,2900
679,17,1,840
182,16,1,660
927,17,7,680
661,18,3,2120
610,18,1,2680
702,18,1,2820
159,16,1,3740
407,18,2,3000
149,16,9,3300
407,18,4,2320
847,18,1,2000
698,16,10,4000
349,17,1,900
702,18,3,2780
711,18,5,2860
407,18,4,2620
847,18,1,2740
595,15,3,780
661,18,2,2200
130,13,8,600
227,16,1,3100
977,16,3,2100
162,14,1,860
732,18,1,2560
732,18,6,2360
302,16,6,3080
208,15,3,4100
698,16,4,3600
679,17,2,540
159,16,7,3180
159,16,3,3160
349,17,1,960
407,18,7,2260
349,17,6,760
847,18,1,2580
270,16,10,760
130,13,2,600
884,13,3,4400
159,16,1,3940
992,16,1,780
679,17,3,740
407,18,3,2220
927,17,1,840
881,14,6,4260
881,14,2,4840
182,16,1,520
349,17,1,620
437,18,5,2780
928,17,8,820
629,16,1,3760
208,15,11,4660
610,18,2,2800
969,17,6,600
593,14,26,3520
299,16,4,940
847,18,14,2740
698,16,3,3240
162,14,3,680
299,16,5,840
944,16,2,3840
227,16,1,3040
166,16,9,3840
629,16,4,3420
280,16,2,640
969,17,1,960
349,17,1,940
679,17,3,520
629,16,3,3120
280,16,4,660
280,16,6,500
732,18,1,2640
437,18,1,2220
267,18,2,2560
299,16,1,920
610,18,6,2440
270,16,1,680
149,16,1,3000
349,17,3,880
126,10,89,3340
977,16,3,2340
992,16,3,720
407,18,11,2180
884,13,2,3080
302,16,2,3540
698,16,2,3680
267,18,11,2580
270,16,3,720
977,16,1,2480
881,14,6,3980
711,18,7,2500
267,18,1,2320
698,16,6,3840
270,16,4,520
928,17,2,600
182,16,3,540
702,18,3,2940
928,17,3,800
679,17,2,720
732,18,18,2220
884,13,1,3680
595,15,5,520
944,16,4,3600
420,18,4,2000
807,4,261,980
270,16,2,800
166,16,3,3940
977,16,2,2720
698,16,3,3340
881,14,1,4100
927,17,2,660
977,16,4,2580
231,18,15,2120
711,18,12,2540
227,16,3,3300
679,17,6,840
231,18,2,2160
411,16,9,3520
299,16,12,840
325,17,5,560
149,16,1,3540
411,16,13,3880
182,16,1,720
927,17,2,960
702,18,11,2340
698,16,2,4000
360,17,1,740
595,15,6,780
944,16,6,3580
884,13,6,3320
227,16,1,3040
554,16,8,3340
928,17,1,920
411,16,4,3980
227,16,1,3400
992,16,4,720
711,18,1,2280
325,17,1,680
420,18,2,2660
645,26,65,1320
732,18,2,2800
267,18,4,2940
360,17,4,800
411,16,6,3860
267,18,5,2680
299,16,3,840
595,15,8,660
325,17,4,560
944,16,5,3660
407,18,6,2300
881,14,11,4080
698,16,2,3460
992,16,1,760
944,16,5,3620
977,16,4,2320
420,18,1,2760
411,16,2,3620
732,18,1,2100
159,16,11,3280
977,16,9,2560
661,18,1,2640
280,16,2,980
267,18,8,2560
349,17,1,880
884,13,1,3420
847,18,3,2080
325,17,4,500
367,16,12,900
944,16,4,3000
130,13,15,760
629,16,2,3500
884,13,2,4300
610,18,2,2000
420,18,2,2700
302,16,6,3160
227,16,4,3060
299,16,2,660
302,16,7,3880
554,16,8,3600
437,18,2,2380
702,18,11,2160
944,16,1,3220
149,16,1,3500
711,18,1,2780
280,16,1,880
927,17,10,820
280,16,1,940
208,15,3,3000
928,17,1,1000
698,16,2,3940
595,15,4,520
884,13,4,3200
554,16,1,3940
231,18,1,2240
182,16,7,680
299,16,5,620
299,16,2,640
130,13,7,960
420,18,6,2300
349,17,2,620
732,18,1,2900
280,16,2,540
977,16,5,2340
928,17,6,620
411,16,6,3900
126,10,31,540
944,16,1,3980
227,16,2,3340
884,13,3,3480
927,17,1,640
595,15,3,820
732,18,3,2700
928,17,1,620
437,18,3,2040
928,17,9,860
884,13,1,3300
360,17,1,580
159,16,16,3280
554,16,7,3320
629,16,10,3120
407,18,7,2620
881,14,1,3680
149,16,2,3960
702,18,6,2740
360,17,1,940
231,18,12,2560
928,17,5,720
349,17,1,640
554,16,4,3780
407,18,3,2480
661,18,2,2500
360,17,2,940
367,16,6,940
162,14,1,740
302,16,1,3240
992,16,2,820
420,18,5,2040
679,17,7,700
130,13,2,700
302,16,5,3160
977,16,8,2320
595,15,8,780
698,16,1,3700
302,16,7,3540
977,16,1,2600
149,16,1,3080
698,16,1,3960
162,14,2,820
977,16,3,2080
944,16,2,3560
325,17,2,580
595,15,3,860
182,16,2,680
267,18,3,2500
162,14,7,780
159,16,16,3840
280,16,2,820
884,13,1,3520
302,16,1,3900
847,18,1,2460
928,17,6,600
698,16,2,3760
231,18,4,2740
149,16,10,3160
629,16,23,3820
847,18,3,2100
969,17,1,780
208,15,1,3540
367,16,5,680
711,18,6,2480
944,16,6,3300
208,15,5,4040
407,18,2,2520
884,13,4,4640
325,17,12,860
881,14,3,3100
360,17,10,1000
679,17,9,700
610,18,2,2040
629,16,4,3940
227,16,1,3440
881,14,12,3180
437,18,2,2420
411,16,4,3120
661,18,4,2620
629,16,4,3160
610,18,13,2520
661,18,3,2800
162,14,1,520
679,17,2,560
595,15,1,880
162,14,1,620
420,18,7,2440
182,16,2,540
969,17,1,740
270,16,2,660
182,16,4,680
267,18,3,2980
886,8,28,4220
702,18,3,2500
928,17,2,980
208,15,3,4500
349,17,1,940
847,18,7,2420
437,18,14,2660
928,17,1,740
629,16,2,3000
884,13,2,3820
162,14,3,860
227,16,1,3460
927,17,2,780
166,16,3,3940
149,16,2,3220
711,18,6,2420
629,16,5,3520
267,18,6,2820
270,16,4,940
159,16,12,3400
360,17,10,820
698,16,5,3180
977,16,1,2760
360,17,6,820
182,16,1,860
182,16,2,980
149,16,6,3420
698,16,12,3080
159,16,3,3220
977,16,2,2700
679,17,5,620
554,16,3,3940
162,14,5,760
360,17,4,740
629,16,1,3940
367,16,4,660
711,18,4,2320
595,15,3,500
302,16,1,3540
977,16,9,2980
420,18,1,2460
130,13,5,940
227,16,1,3940
231,18,1,2140
847,18,9,2120
661,18,7,2760
884,13,2,4120
411,16,20,3960
944,16,2,3320
420,18,1,2940
661,18,1,2600
992,16,9,780
162,14,1,500
702,18,7,2300
130,13,10,720
661,18,1,2040
162,14,4,680
166,16,6,3200
732,18,2,2980
881,14,6,4680
149,16,4,3020
977,16,5,2700
702,18,3,2740
267,18,4,2260
661,18,1,2860
166,16,1,3860
407,18,1,2180
698,16,3,3400
711,18,2,2520
349,17,6,740
610,18,2,2260
182,16,3,740
702,18,2,2820
166,16,1,3080
227,16,1,3620
280,16,7,660
992,16,1,640
299,16,1,980
360,17,3,820
847,18,2,2100
407,18,5,2540
302,16,11,3800
610,18,3,2300
969,17,2,500
884,13,1,4940
367,16,6,760
884,13,5,4940
267,18,4,2320
437,18,6,2080
208,15,3,3040
231,18,21,2140
927,17,1,760
661,18,13,3000
367,16,1,740
270,16,10,840
679,17,17,640
299,16,1,800"""


N_FIELDS = 3

def get_answer():
    ans = []
    if SIRIUS:
        for i in range(sirius_ans_obj.elements):
            elem = sirius_ans_obj.answer(element=i)
            if elem is None:
                elem = ""
            ans.append(elem.strip())
    elif POLYGON or SILVER:
        ans = []
        if POLYGON:
            fin = open(sys.argv[2], "r", encoding="utf8")
        elif SILVER:
            fin = sys.stdin
        for elem in fin:
            ans.append(elem.strip())
        ans = ans[:N_FIELDS]
        while len(ans) < N_FIELDS:
            ans.append("")
    return ans


def clean(ans):
    ans = ans.upper()
    for a, b in {
        " ": "",
        ",": "",
        ";": "",
        ".": "",
        "'": "",  # Одинарная кавычка
        '"': "",  # Двойная кавычка
        "<": "",
        ">": "",
        chr(0x00AB): "",
        chr(0x00BB): "",
        chr(0x2018): "",
        chr(0x2019): "",
        chr(0x201A): "",
        chr(0x201C): "",
        chr(0x201D): "",
        chr(0x201E): "",
        chr(0x2039): "",
        chr(0x203A): "",
        'А': 'A',
        'В': 'B',
        'Е': 'E',
        'З': '3',
        'И': 'U',
        'К': 'K',
        'М': 'M',
        'Н': 'H',
        'О': 'O',
        'Р': 'P',
        'С': 'C',
        'Т': 'T',
        'У': 'Y',
        'Х': 'X',
        'Ч': '4',
        'Ь': 'B',
    }.items():
        ans = ans.replace(a, b)
    return ans


ans_list = get_answer()

if len(ans_list) != N_FIELDS:
    quit(PE, "В ответе должно быть ровно три числа")

for i in range(len(ans_list)):
    ans_list[i] = ans_list[i].strip()


if ans_list[0].isdigit():
    par_date = int(ans_list[0])
else:
    par_date = -1
par_num = ans_list[1]
if ans_list[2].isdigit():
    par_price = int(ans_list[2])
else:
    par_price = -1

# solve

from collections import defaultdict

tickets = defaultdict(lambda: [])
date = defaultdict(lambda: 0)

for line in data.split():
    num, dt, cnt, price = line.split(",")
    dt, cnt, price = map(int, [dt, cnt, price])
    if dt <= 20:
        tickets[num].append((cnt, price))
    date[num] = dt

ans_date = -1
ans_price = 0
ans_num = ""

train_price = defaultdict(lambda: 0)
for num in tickets:
    cnt = 0
    tickets[num].sort(key=lambda x: x[1])
    left = 100
    total = 0
    for a, b in tickets[num]:
        total += min(a, left) * b
        left -= min(a, left)
    if left:
        continue

    train_price[num] = total
    if date[num] > ans_date or (date[num] == ans_date and total < ans_price):
        ans_num = num
        ans_date = date[num]
        ans_price = total

# scoring

if par_num not in date:
    if par_date == ans_date:
        if par_price == ans_price:
            quit(WA, "Номер поезда неверный, но правильная дата и цена", 60)
        else:
            quit(WA, "Номер поезда неверный, но правильная дата", 30)
    else:
        if par_price == ans_price:
            quit(WA, "Номер поезда неверный, но правильная цена", 30)
        else:
            quit(WA, "Все ответы неверные", 0)

if par_num == ans_num:
    if par_date == ans_date:
        if par_price == ans_price:
            quit(OK, "Все ответы верны", 100)
        else:
            quit(WA, "Верная дата и номер поезда", 70)
    else:
        if par_price == ans_price:
            quit(WA, "Верный номер поезда и цена", 70)
        else:
            quit(WA, "Правильно указан только номер поезда", 40)

if par_num in train_price:  # has 100 seats
    add_score = 20 * int(par_date in [date[par_num], ans_date]) + 20 * int(
        par_price in [train_price[par_num], ans_price])
    if date[par_num] == ans_date:  # suboptimal in correct day
        quit(WA, "Правильная дата, но выбран не самый дешёвый поезд",
             30 + add_score)
    elif date[par_num] < ans_date:
        quit(WA, "Не лучшая дата, но в эту дату можно выбрать подходящий поезд",
             20 + add_score)
    elif date[par_num] > 20:
        quit(WA, "Дата после начала олимпиады",
             0 + add_score)
    else:
        quit(CF, "Решение жюри не самое лучшее :(")

else:
    if date[par_num] <= 20:
        add_score = 20 * int(par_date in [date[par_num], ans_date]) + 20 * int(
            par_price == ans_price)
        quit(WA, "Not enough seats on the train", 5 + add_score)
    else:
        add_score = 10 * int(par_date in [date[par_num], ans_date]) + 10 * int(
            par_price == ans_price)
        quit(WA, "Train after deadline", 0 + add_score)
